@@ -1,9 +1,10 @@
 #include "cpu.h"
-#include "common/io/io.h"
+#include "common/io.h"
 #include "common/processing.h"
 #include "common/properties.h"
-#include "util/mallocHelper.h"
-#include "util/stringUtils.h"
+#include "common/mallocHelper.h"
+#include "common/stringUtils.h"
+#include "common/path.h"
 
 #include <sys/sysinfo.h>
 #include <stdlib.h>
@@ -13,6 +14,18 @@
 
 #define FF_CPUINFO_PATH "/proc/cpuinfo"
 
+static double readTempFile(int dfd, const char* filename, FFstrbuf* buffer)
+{
+    if (filename ? !ffReadFileBufferRelative(dfd, filename, buffer) : !ffReadFDBuffer(dfd, buffer))
+        return FF_CPU_TEMP_UNSET;
+
+    double value = ffStrbufToDouble(buffer, FF_CPU_TEMP_UNSET); // millidegree Celsius
+    if (value == FF_CPU_TEMP_UNSET)
+        return FF_CPU_TEMP_UNSET;
+
+    return value / 1000.;
+}
+
 static double parseTZDir(int dfd, FFstrbuf* buffer)
 {
     if (!ffReadFileBufferRelative(dfd, "type", buffer))
@@ -26,18 +39,12 @@ static double parseTZDir(int dfd, FFstrbuf* buffer)
         true
     ) return FF_CPU_TEMP_UNSET;
 
-    if (!ffReadFileBufferRelative(dfd, "temp", buffer))
-        return FF_CPU_TEMP_UNSET;
-
-    double value = ffStrbufToDouble(buffer, FF_CPU_TEMP_UNSET);// millidegree Celsius
-    if (value == FF_CPU_TEMP_UNSET)
-        return FF_CPU_TEMP_UNSET;
-
-    return value / 1000.;
+    return readTempFile(dfd, "temp", buffer);
 }
 
 static double parseHwmonDir(int dfd, FFstrbuf* buffer)
 {
+    //https://www.kernel.org/doc/Documentation/hwmon/sysfs-interface
     if (!ffReadFileBufferRelative(dfd, "name", buffer))
         return FF_CPU_TEMP_UNSET;
 
@@ -53,25 +60,64 @@ static double parseHwmonDir(int dfd, FFstrbuf* buffer)
         true
     ) return FF_CPU_TEMP_UNSET;
 
-    //https://www.kernel.org/doc/Documentation/hwmon/sysfs-interface
-    if (!ffReadFileBufferRelative(dfd, "temp1_input", buffer))
-        return FF_CPU_TEMP_UNSET;
-
-    double value = ffStrbufToDouble(buffer, FF_CPU_TEMP_UNSET);// millidegree Celsius
-    if (value == FF_CPU_TEMP_UNSET)
-        return FF_CPU_TEMP_UNSET;
-
-    return value / 1000.;
+    return readTempFile(dfd, "temp1_input", buffer);
 }
 
-static double detectCPUTemp(void)
+static double detectCPUTemp(const FFCPUOptions* options)
 {
     FF_STRBUF_AUTO_DESTROY buffer = ffStrbufCreate();
+
+    if (options->tempSensor.length > 0)
+    {
+        FF_AUTO_CLOSE_FD int subfd = -1;
+        const char* fileName = NULL;
+        if (ffStrbufStartsWithS(&options->tempSensor, "hwmon") && ffCharIsDigit(options->tempSensor.chars[strlen("hwmon")]))
+        {
+            FF_AUTO_CLOSE_FD int dfd = open("/sys/class/hwmon/", O_PATH | O_CLOEXEC);
+            subfd = openat(dfd, options->tempSensor.chars, O_RDONLY | O_DIRECTORY | O_CLOEXEC);
+            if (subfd >= 0)
+                fileName = "temp1_input";
+            else
+                subfd = openat(dfd, options->tempSensor.chars, O_RDONLY | O_CLOEXEC);
+        }
+        else if (ffStrbufStartsWithS(&options->tempSensor, "thermal_zone") && ffCharIsDigit(options->tempSensor.chars[strlen("thermal_zone")]))
+        {
+            FF_AUTO_CLOSE_FD int dfd = open("/sys/class/thermal/", O_PATH | O_CLOEXEC);
+            subfd = openat(dfd, options->tempSensor.chars, O_RDONLY | O_DIRECTORY | O_CLOEXEC);
+            if (subfd >= 0)
+                fileName = "temp";
+            else
+                subfd = openat(dfd, options->tempSensor.chars, O_RDONLY | O_CLOEXEC);
+        }
+        else if (ffStrbufStartsWithS(&options->tempSensor, "cputemp.") && ffCharIsDigit(options->tempSensor.chars[strlen("cputemp.")]))
+        {
+            FF_AUTO_CLOSE_FD int dfd = open("/sys/class/platform/", O_PATH | O_CLOEXEC);
+            subfd = openat(dfd, options->tempSensor.chars, O_RDONLY | O_DIRECTORY | O_CLOEXEC);
+            if (subfd >= 0)
+                fileName = "temp1_input";
+            else
+                subfd = openat(dfd, options->tempSensor.chars, O_RDONLY | O_CLOEXEC);
+        }
+        else if (ffIsAbsolutePath(options->tempSensor.chars))
+        {
+            subfd = open(options->tempSensor.chars, O_RDONLY | O_DIRECTORY | O_CLOEXEC);
+            if (subfd >= 0)
+                fileName = "temp1_input";
+            else
+                subfd = open(options->tempSensor.chars, O_RDONLY | O_CLOEXEC);
+        }
+        if (subfd < 0)
+            return FF_CPU_TEMP_UNSET;
+
+        return readTempFile(subfd, fileName, &buffer);
+    }
+
     {
         FF_AUTO_CLOSE_DIR DIR* dirp = opendir("/sys/class/hwmon/");
         if(dirp)
         {
             int dfd = dirfd(dirp);
+
             struct dirent* entry;
             while((entry = readdir(dirp)) != NULL)
             {
@@ -138,6 +184,21 @@ static double detectCPUTemp(void)
     return FF_CPU_TEMP_UNSET;
 }
 
+static void detectNumaNodes(FFCPUResult* cpu)
+{
+    FF_AUTO_CLOSE_DIR DIR* dir = opendir("/sys/devices/system/node/");
+    if (!dir) return;
+
+    struct dirent* entry;
+    while ((entry = readdir(dir)) != NULL)
+    {
+        if (entry->d_type != DT_DIR && entry->d_type != DT_UNKNOWN)
+            continue;
+        if (ffStrStartsWith(entry->d_name, "node") && ffCharIsDigit(entry->d_name[strlen("node")]))
+            cpu->numaNodes++;
+    }
+}
+
 #ifdef __ANDROID__
 #include "common/settings.h"
 
@@ -408,9 +469,9 @@ static const char* parseCpuInfo(
             (cpuIsa->length == 0 && ffParsePropLine(line, "isa :", cpuIsa)) ||
             (cpuUarch->length == 0 && ffParsePropLine(line, "uarch :", cpuUarch)) ||
             #elif __s390x__
-            (cpu->name.length == 0 && ffParsePropLine(line, "processor 0:", &cpu->name)) ||
+            (cpu->name.length == 0 && ffParsePropLine(line, "machine :", &cpu->name)) ||
             (cpu->vendor.length == 0 && ffParsePropLine(line, "vendor_id :", &cpu->vendor)) ||
-            (cpuMHz->length == 0 && ffParsePropLine(line, "cpu MHz static :", cpuMHz)) || // This one cannot be detected because of early return
+            (cpuMHz->length == 0 && ffParsePropLine(line, "cpu MHz static :", cpuMHz)) ||
             #elif __ia64__
             (cpu->name.length == 0 && ffParsePropLine(line, "model name :", &cpu->name)) ||
             (cpu->vendor.length == 0 && ffParsePropLine(line, "vendor :", &cpu->vendor)) ||
@@ -568,6 +629,8 @@ FF_MAYBE_UNUSED static const char* detectCPUX86(const FFCPUOptions* options, FFC
     if (!detectFrequency(cpu, options) || cpu->frequencyBase == 0)
         cpu->frequencyBase = (uint32_t) ffStrbufToUInt(&cpuMHz, 0);
 
+    detectNumaNodes(cpu);
+
     return NULL;
 }
 
@@ -678,7 +741,7 @@ FF_MAYBE_UNUSED static void detectSocName(FFCPUResult* cpu)
 
     // [x-vendor,x-model\0]*N
     char content[512];
-    ssize_t length = ffReadFileData("/proc/device-tree/compatible", ARRAY_SIZE(content), content);
+    ssize_t length = ffReadFileData("/sys/firmware/devicetree/base/compatible", ARRAY_SIZE(content), content);
     if (length < 4) return; // v,m\0
 
     if (content[length - 1] != '\0') return; // must end with \0
@@ -799,9 +862,9 @@ FF_MAYBE_UNUSED static uint16_t getLoongarchPropCount(FFstrbuf* cpuinfo, const c
         char* pend;
         unsigned long id = strtoul(p, &pend, 10);
         if (__builtin_expect(id > 64, false))
-            high |= 1 << (id - 64);
+            high |= 1UL << (id - 64);
         else
-            low |= 1 << id;
+            low |= 1UL << id;
         p = pend;
     }
 
@@ -868,8 +931,7 @@ FF_MAYBE_UNUSED static const char* detectCPUOthers(const FFCPUOptions* options,
         cpu->coresPhysical = getLoongarchPropCount(&cpuinfo, "\ncore\t\t\t:");
         if (cpu->packages > 1) cpu->coresPhysical *= cpu->packages;
         #elif __s390x__
-        if (ffStrbufSubstrAfterFirstS(&cpu->name, "machine = "))
-            ffStrbufPrependS(&cpu->name, "Machine ");
+        if (cpu->name.length) ffStrbufPrependS(&cpu->name, "Machine ");
         #endif
     }
 
@@ -877,6 +939,7 @@ FF_MAYBE_UNUSED static const char* detectCPUOthers(const FFCPUOptions* options,
         detectPhysicalCores(cpu);
 
     ffCPUDetectByCpuid(cpu);
+    detectNumaNodes(cpu);
 
     return NULL;
 }
@@ -884,7 +947,7 @@ FF_MAYBE_UNUSED static const char* detectCPUOthers(const FFCPUOptions* options,
 
 const char* ffDetectCPUImpl(const FFCPUOptions* options, FFCPUResult* cpu)
 {
-    cpu->temperature = options->temp ? detectCPUTemp() : FF_CPU_TEMP_UNSET;
+    cpu->temperature = options->temp ? detectCPUTemp(options) : FF_CPU_TEMP_UNSET;
 
     #if __x86_64__ || __i386__
     return detectCPUX86(options, cpu);
