@@ -1,5 +1,5 @@
 #include "common/font.h"
-#include "common/io/io.h"
+#include "common/io.h"
 #include "font.h"
 
 #import <AppKit/NSFont.h>
@@ -25,7 +25,11 @@ const char* ffDetectFontImpl(FFFontResult* result)
 {
     ffStrbufAppendS(&result->fonts[0], [NSFont systemFontOfSize:12].familyName.UTF8String);
     ffStrbufAppendS(&result->fonts[1], [NSFont userFontOfSize:12].familyName.UTF8String);
+    #ifdef MAC_OS_X_VERSION_10_15
     ffStrbufAppendS(&result->fonts[2], [NSFont monospacedSystemFontOfSize:12 weight:400].familyName.UTF8String);
+    #else
+    ffStrbufAppendS(&result->fonts[2], "");
+    #endif
     ffStrbufAppendS(&result->fonts[3], [NSFont userFixedPitchFontOfSize:12].familyName.UTF8String);
     generateString(result);
 
