@@ -1,9 +1,9 @@
 #include "common/percent.h"
 #include "common/printing.h"
 #include "common/jsonconfig.h"
+#include "common/stringUtils.h"
 #include "detection/bluetoothradio/bluetoothradio.h"
 #include "modules/bluetoothradio/bluetoothradio.h"
-#include "util/stringUtils.h"
 
 #define FF_BLUETOOTHRADIO_DISPLAY_NAME "Bluetooth Radio"
 
@@ -67,7 +67,7 @@ static void printDevice(FFBluetoothRadioOptions* options, const FFBluetoothRadio
     }
 }
 
-void ffPrintBluetoothRadio(FFBluetoothRadioOptions* options)
+bool ffPrintBluetoothRadio(FFBluetoothRadioOptions* options)
 {
     FF_LIST_AUTO_DESTROY radios = ffListCreate(sizeof (FFBluetoothRadioResult));
     const char* error = ffDetectBluetoothRadio(&radios);
@@ -75,26 +75,25 @@ void ffPrintBluetoothRadio(FFBluetoothRadioOptions* options)
     if(error)
     {
         ffPrintError(FF_BLUETOOTHRADIO_DISPLAY_NAME, 0, &options->moduleArgs, FF_PRINT_TYPE_DEFAULT, "%s", error);
+        return false;
     }
-    else
+
+    uint8_t index = 0;
+    FF_LIST_FOR_EACH(FFBluetoothRadioResult, radio, radios)
     {
-        uint8_t index = 0;
-        FF_LIST_FOR_EACH(FFBluetoothRadioResult, radio, radios)
-        {
-            if (!radio->enabled)
-                continue;
+        if (!radio->enabled)
+            continue;
 
-            index++;
-            printDevice(options, radio, index);
-        }
+        index++;
+        printDevice(options, radio, index);
+    }
 
-        if (index == 0)
-        {
-            if (radios.length > 0)
-                ffPrintError(FF_BLUETOOTHRADIO_DISPLAY_NAME, 0, &options->moduleArgs, FF_PRINT_TYPE_DEFAULT, "Bluetooth radios found but none enabled");
-            else
-                ffPrintError(FF_BLUETOOTHRADIO_DISPLAY_NAME, 0, &options->moduleArgs, FF_PRINT_TYPE_DEFAULT, "No devices detected");
-        }
+    if (index == 0)
+    {
+        if (radios.length > 0)
+            ffPrintError(FF_BLUETOOTHRADIO_DISPLAY_NAME, 0, &options->moduleArgs, FF_PRINT_TYPE_DEFAULT, "Bluetooth radios found but none enabled");
+        else
+            ffPrintError(FF_BLUETOOTHRADIO_DISPLAY_NAME, 0, &options->moduleArgs, FF_PRINT_TYPE_DEFAULT, "No devices detected");
     }
 
     FF_LIST_FOR_EACH(FFBluetoothRadioResult, radio, radios)
@@ -103,6 +102,7 @@ void ffPrintBluetoothRadio(FFBluetoothRadioOptions* options)
         ffStrbufDestroy(&radio->address);
         ffStrbufDestroy(&radio->vendor);
     }
+    return true;
 }
 
 void ffParseBluetoothRadioJsonObject(FFBluetoothRadioOptions* options, yyjson_val* module)
@@ -123,7 +123,7 @@ void ffGenerateBluetoothRadioJsonConfig(FFBluetoothRadioOptions* options, yyjson
     ffJsonConfigGenerateModuleArgsConfig(doc, module, &options->moduleArgs);
 }
 
-void ffGenerateBluetoothRadioJsonResult(FF_MAYBE_UNUSED FFBluetoothRadioOptions* options, yyjson_mut_doc* doc, yyjson_mut_val* module)
+bool ffGenerateBluetoothRadioJsonResult(FF_MAYBE_UNUSED FFBluetoothRadioOptions* options, yyjson_mut_doc* doc, yyjson_mut_val* module)
 {
     FF_LIST_AUTO_DESTROY results = ffListCreate(sizeof(FFBluetoothRadioResult));
 
@@ -131,7 +131,7 @@ void ffGenerateBluetoothRadioJsonResult(FF_MAYBE_UNUSED FFBluetoothRadioOptions*
     if (error)
     {
         yyjson_mut_obj_add_str(doc, module, "error", error);
-        return;
+        return false;
     }
 
     yyjson_mut_val* arr = yyjson_mut_obj_add_arr(doc, module, "result");
@@ -161,6 +161,8 @@ void ffGenerateBluetoothRadioJsonResult(FF_MAYBE_UNUSED FFBluetoothRadioOptions*
         ffStrbufDestroy(&radio->address);
         ffStrbufDestroy(&radio->vendor);
     }
+
+    return true;
 }
 
 void ffInitBluetoothRadioOptions(FFBluetoothRadioOptions* options)
