@@ -1,18 +1,18 @@
 #include "common/printing.h"
 #include "common/jsonconfig.h"
+#include "common/stringUtils.h"
 #include "detection/displayserver/displayserver.h"
 #include "detection/de/de.h"
 #include "modules/de/de.h"
-#include "util/stringUtils.h"
 
-void ffPrintDE(FFDEOptions* options)
+bool ffPrintDE(FFDEOptions* options)
 {
     const FFDisplayServerResult* result = ffConnectDisplayServer();
 
     if(result->dePrettyName.length == 0)
     {
         ffPrintError(FF_DE_MODULE_NAME, 0, &options->moduleArgs, FF_PRINT_TYPE_DEFAULT, "No DE found");
-        return;
+        return false;
     }
 
     FF_STRBUF_AUTO_DESTROY version = ffStrbufCreate();
@@ -40,6 +40,8 @@ void ffPrintDE(FFDEOptions* options)
             FF_FORMAT_ARG(version, "version")
         }));
     }
+
+    return true;
 }
 
 void ffParseDEJsonObject(FFDEOptions* options, yyjson_val* module)
@@ -53,7 +55,7 @@ void ffParseDEJsonObject(FFDEOptions* options, yyjson_val* module)
 
         if (unsafe_yyjson_equals_str(key, "slowVersionDetection"))
         {
-            options->slowVersionDetection = yyjson_get_bool(val);
+            ffPrintError(FF_DE_MODULE_NAME, 0, &options->moduleArgs, FF_PRINT_TYPE_DEFAULT, "Key `slowVersionDetection` is deprecated, it's always true");
             continue;
         }
 
@@ -64,18 +66,16 @@ void ffParseDEJsonObject(FFDEOptions* options, yyjson_val* module)
 void ffGenerateDEJsonConfig(FFDEOptions* options, yyjson_mut_doc* doc, yyjson_mut_val* module)
 {
     ffJsonConfigGenerateModuleArgsConfig(doc, module, &options->moduleArgs);
-
-    yyjson_mut_obj_add_bool(doc, module, "slowVersionDetection", options->slowVersionDetection);
 }
 
-void ffGenerateDEJsonResult(FF_MAYBE_UNUSED FFDEOptions* options, yyjson_mut_doc* doc, yyjson_mut_val* module)
+bool ffGenerateDEJsonResult(FF_MAYBE_UNUSED FFDEOptions* options, yyjson_mut_doc* doc, yyjson_mut_val* module)
 {
     const FFDisplayServerResult* result = ffConnectDisplayServer();
 
     if(result->dePrettyName.length == 0)
     {
         yyjson_mut_obj_add_str(doc, module, "error", "No DE found");
-        return;
+        return false;
     }
 
     FF_STRBUF_AUTO_DESTROY version = ffStrbufCreate();
@@ -85,13 +85,12 @@ void ffGenerateDEJsonResult(FF_MAYBE_UNUSED FFDEOptions* options, yyjson_mut_doc
     yyjson_mut_obj_add_strbuf(doc, obj, "processName", &result->deProcessName);
     yyjson_mut_obj_add_strbuf(doc, obj, "prettyName", &result->dePrettyName);
     yyjson_mut_obj_add_strbuf(doc, obj, "version", &version);
+    return true;
 }
 
 void ffInitDEOptions(FFDEOptions* options)
 {
     ffOptionInitModuleArg(&options->moduleArgs, "");
-
-    options->slowVersionDetection = false;
 }
 
 void ffDestroyDEOptions(FFDEOptions* options)
