@@ -1,6 +1,6 @@
 #pragma once
 
-#include "util/FFstrbuf.h"
+#include "common/ffdata.h"
 
 typedef enum __attribute__((__packed__)) FFDsForceDrmType
 {
@@ -28,4 +28,4 @@ const char* ffOptionsParseGeneralJsonConfig(FFOptionsGeneral* options, yyjson_va
 bool ffOptionsParseGeneralCommandLine(FFOptionsGeneral* options, const char* key, const char* value);
 void ffOptionsInitGeneral(FFOptionsGeneral* options);
 void ffOptionsDestroyGeneral(FFOptionsGeneral* options);
-void ffOptionsGenerateGeneralJsonConfig(FFOptionsGeneral* options, yyjson_mut_doc* doc);
+void ffOptionsGenerateGeneralJsonConfig(FFdata* data, FFOptionsGeneral* options);
